justaddpower

package module
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2020 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type JustAddPowerChannelIntResult

type JustAddPowerChannelIntResult struct {
	Data int `json:"data"`
}

JustAddPowerChannelIntResult type for result

type JustAddPowerChannelResult

type JustAddPowerChannelResult struct {
	Data string `json:"data"`
}

JustAddPowerChannelResult type for result

type JustAddPowerDetailsResult

type JustAddPowerDetailsResult struct {
	Data struct {
		Firmware struct {
			Date   string `json:"date"`
			Update struct {
				Eta      bool   `json:"eta"`
				Message  string `json:"message"`
				Progress bool   `json:"progress"`
				Result   bool   `json:"result"`
				Status   bool   `json:"status"`
			} `json:"update"`
			Version string `json:"version"`
		} `json:"firmware"`
		Model   string `json:"model"`
		Network struct {
			Ipaddress string `json:"ipaddress"`
			Mac       string `json:"mac"`
			Mtu       int    `json:"mtu"`
			Netmask   string `json:"netmask"`
			Speed     string `json:"speed"`
		} `json:"network"`
		Status string `json:"status"`
		Time   string `json:"time"`
		Uptime string `json:"uptime"`
	} `json:"data"`
}

JustAddPowerDetailsResult type for the hardware details stuff

type JustAddPowerReciever

type JustAddPowerReciever struct {
	Address string
}

func (*JustAddPowerReciever) GetAudioVideoInputs added in v0.1.2

func (j *JustAddPowerReciever) GetAudioVideoInputs(ctx context.Context) (map[string]string, error)

GetAudioVideoInputs returns the current input

func (*JustAddPowerReciever) GetHardwareInfo

func (j *JustAddPowerReciever) GetHardwareInfo(ctx context.Context) (structs.HardwareInfo, error)

GetHardwareInfo returns a hardware info struct

func (*JustAddPowerReciever) GetInfo

func (j *JustAddPowerReciever) GetInfo(ctx context.Context) (interface{}, error)

GetInfo .

func (*JustAddPowerReciever) SetAudioVideoInput added in v0.1.3

func (j *JustAddPowerReciever) SetAudioVideoInput(ctx context.Context, output, input string) error

SwitchInput changes the input on the given output to input (Just add power transmitter - ipaddr) We don't need the output necessarily because the reciever is the output

Jump to